pub fn remove_node_with_data(
registry: &mut NodeRegistry,
name_or_id: &str,
) -> Result<(), IntersticeError>Expand description
Remove a node from the registry and clean up its local data directory if it’s a local node
pub fn remove_node_with_data(
registry: &mut NodeRegistry,
name_or_id: &str,
) -> Result<(), IntersticeError>Remove a node from the registry and clean up its local data directory if it’s a local node